##########
#
#  Copyright 2002, Tom Hoffman.
# 
#  This file is part of Tuttle.
#
#  Tuttle is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  Tuttle is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with Tuttle (see COPYING.txt); if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
##########

from OFS.Folder import Folder
from Globals import DTMLFile
from StudentsFolder import StudentsFolder
from TeachersFolder import TeachersFolder

# module level declarations and methods

manage_addSchoolInfoForm = DTMLFile("dtml/addSchoolInfoForm", globals())

def manage_addSchoolInfo(self,id,title,\
district,superintendent,REQUEST):
	"Method for adding a Tuttle site"
	newSchool = SchoolInfo(id,title,district,superintendent)
	# add a folder for students
	studFolder=StudentsFolder('students', title + ' Student Records')
	newSchool._setObject('students',studFolder)
	# add a folder for teachers
	teachFolder=TeachersFolder('teachers', title + ' Teacher Files')
	newSchool._setObject('teachers',teachFolder)

	self._setObject(id, newSchool)
	return self.manage_main(self, REQUEST)

class SchoolInfo(Folder):
        "The SchoolInfo Class"
	meta_type = "Tuttle School Site"
        
        # Class Level Defaults
        #
        # List of options for student and class GradeLevel 
        # These must be customized for each school
        # To do:
        #   Fix this so these can be set through the web
        #   without having to be reset with each upgrade
                
        # A list of the grades or levels in the school
        # e.g., in traditional (high) schools, GradeLevelList would be ['9','10','11','12']
        GradeLevelList=['School One', 'School Two']
        
        # If students and teachers are organized into teams, academies, etc.
        TeamList=['1','2','3','School 2']
        TeacherTeamList=TeamList
        
        # These need to be updated in a few years...
        # Graduation Years
        GradYearList=["2003","2004","2005","2006","2007","2008"]

	def __init__ (self, id, title,\
	district="Unknown School District", \
        superintendent="Unknown"):
		"To do: add more of the attributes in the SIF model."
		self.id=id
		self.title=title # maps to SIF.SchoolInfo.SchoolName
		self.district=district
		self.superintendent=superintendent
	
	# set up our management tabs
	manage_options=(
	{'label':'Contents','action':'manage_main'},
	{'label':'View','action':'index_html'}, 
	{'label':'School Info','action':'manage_edit'},
	{'label':'Security','action':'manage_access'},
	{'label':'Undo','action':'manage_UndoForm'},	
	{'label':'Find','action':'manage_findForm'},
	{'label':'Properties','action':'manage_propertiesForm'},
	)
	
	# declare properties
	_properties=(
	{'id':'title', 'type':'string'},
	{'id':'district', 'type':'string'},
	{'id':'superintendent','type':'string'}
	)

	# Class level functions and (web) methods 
	manage_edit=DTMLFile("dtml/mainSchoolInfo", globals())
	index_html=DTMLFile("dtml/indexSchoolInfo", globals())

	def editSchoolInfo(self, title, district, superintendent,REQUEST):
		"Edit School Properties"
		
		self.title=title
		self.district=district
		self.superintendent=superintendent

		return self.index_html(self, REQUEST)

	
